@@ -7,7 +7,7 @@ from .borg_job import BorgJob
 class BorgDeleteJob(BorgJob):
     def started_event(self):
         self.app.backup_started_event.emit()
-        self.app.backup_progress_event.emit(self.tr('Deleting archive…'))
+        self.app.backup_progress_event.emit(f"[{self.params['profile_name']}] {self.tr('Deleting archive…')}")
 
     def finished_event(self, result):
         # set repo stats to N/A
@@ -20,7 +20,7 @@ class BorgDeleteJob(BorgJob):
 
         self.app.backup_finished_event.emit(result)
         self.result.emit(result)
-        self.app.backup_progress_event.emit(self.tr('Archive deleted.'))
+        self.app.backup_progress_event.emit(f"[{self.params['profile_name']}] {self.tr('Archive deleted.')}")
 
     @classmethod
     def prepare(cls, profile, archives: List[str]):
