@@ -5,11 +5,13 @@ from .borg_job import BorgJob
 class BorgListArchiveJob(BorgJob):
     def started_event(self):
         self.app.backup_started_event.emit()
-        self.app.backup_progress_event.emit(self.tr('Getting archive content…'))
+        self.app.backup_progress_event.emit(f"[{self.params['profile_name']}] {self.tr('Getting archive content…')}")
 
     def finished_event(self, result):
         self.app.backup_finished_event.emit(result)
-        self.app.backup_progress_event.emit(self.tr('Done getting archive content.'))
+        self.app.backup_progress_event.emit(
+            f"[{self.params['profile_name']}] {self.tr('Done getting archive content.')}"
+        )
         self.result.emit(result)
 
     @classmethod
