@@ -6,9 +6,10 @@ from dataclasses import dataclass
 from pathlib import PurePath
 from typing import List, Optional, Tuple
 from PyQt5 import uic
-from PyQt5.QtCore import QMimeData, QModelIndex, QPoint, Qt, QThread, QUrl
+from PyQt5.QtCore import QDateTime, QLocale, QMimeData, QModelIndex, QPoint, Qt, QThread, QUrl
 from PyQt5.QtGui import QColor, QKeySequence
 from PyQt5.QtWidgets import QApplication, QHeaderView, QMenu, QShortcut, QTreeView
+from vorta.store.models import SettingsModel
 from vorta.utils import get_asset, pretty_bytes, uses_dark_mode
 from vorta.views.partials.treemodel import (
     FileSystemItem,
@@ -98,6 +99,8 @@ class DiffResultDialog(DiffResultBase, DiffResultUI):
         self.archiveNameLabel_2.setText(f'{archive_older.name}')
 
         self.comboBoxDisplayMode.currentIndexChanged.connect(self.change_display_mode)
+        diff_result_display_mode = SettingsModel.get(key='diff_files_display_mode').str_value
+        self.comboBoxDisplayMode.setCurrentIndex(int(diff_result_display_mode))
         self.bFoldersOnTop.toggled.connect(self.sortproxy.keepFoldersOnTop)
         self.bCollapseAll.clicked.connect(self.treeView.collapseAll)
 
@@ -183,6 +186,10 @@ class DiffResultDialog(DiffResultBase, DiffResultUI):
         else:
             raise Exception("Unknown item in comboBoxDisplayMode with index {}".format(selection))
 
+        SettingsModel.update({SettingsModel.str_value: str(selection)}).where(
+            SettingsModel.key == 'diff_files_display_mode'
+        ).execute()
+
         self.model.setMode(mode)
 
     def slot_sorted(self, column, order):
@@ -206,6 +213,8 @@ def parse_diff_json(diffs: List[dict], model: 'DiffTree'):
         change_type: ChangeType = None
         mode_change: Optional[Tuple[str, str]] = None
         owner_change: Optional[Tuple[str, str, str, str]] = None
+        ctime_change: Optional[Tuple[QDateTime, QDateTime]] = None
+        mtime_change: Optional[Tuple[QDateTime, QDateTime]] = None
         modified: Optional[Tuple[int, int]] = None
 
         # added link, removed link, changed link
@@ -213,6 +222,8 @@ def parse_diff_json(diffs: List[dict], model: 'DiffTree'):
         # added directory, removed directory
         # owner (old_user, new_user, old_group, new_group))
         # mode (old_mode, new_mode)
+        # ctime (old_ctime, new_ctime)
+        # mtime (old_mtime, new_mtime)
         for change in item['changes']:
             # if more than one type of change has happened for this file/dir/link, then report the most important
             # (higher priority)
@@ -269,6 +280,22 @@ def parse_diff_json(diffs: List[dict], model: 'DiffTree'):
                     change['new_user'],
                     change['new_group'],
                 )
+
+            elif change['type'] == 'ctime':
+                # ctime change can occur along with previous changes
+                change_type = ChangeType.MODIFIED
+                ctime_change = (
+                    QDateTime.fromString(change['old_ctime'], Qt.DateFormat.ISODateWithMs),
+                    QDateTime.fromString(change['new_ctime'], Qt.DateFormat.ISODateWithMs),
+                )
+            elif change['type'] == 'mtime':
+                # mtime change can occur along with previous changes
+                change_type = ChangeType.MODIFIED
+                mtime_change = (
+                    QDateTime.fromString(change['old_mtime'], Qt.DateFormat.ISODateWithMs),
+                    QDateTime.fromString(change['new_mtime'], Qt.DateFormat.ISODateWithMs),
+                )
+
             else:
                 raise Exception('Unknown change type: {}'.format(change['type']))
 
@@ -282,6 +309,8 @@ def parse_diff_json(diffs: List[dict], model: 'DiffTree'):
                     size=size,
                     mode_change=mode_change,
                     owner_change=owner_change,
+                    ctime_change=ctime_change,
+                    mtime_change=mtime_change,
                     modified=modified,
                 ),
             )
@@ -492,6 +521,8 @@ class ChangeType(enum.Enum):
                     such as - a file is deleted and replaced with
                     a directory of the same name.
     owner - user and/or group ownership changed.
+    ctime - creation time changed.
+    mtime - modification time changed.
 
     size:
         If type == `added` or `removed`,
@@ -518,6 +549,14 @@ class ChangeType(enum.Enum):
         See old_user property.
     new_group:
         See old_user property.
+    old_ctime:
+        If type == `ctime`, then old_ctime and new_ctime provide creation time changes.
+    new_ctime:
+        See old_ctime property.
+    old_mtime:
+        If type == `mtime`, then old_mtime and new_mtime provide modification time changes.
+    new_mtime:
+        See old_mtime property.
     """
 
     NONE = 0  # no change
@@ -531,6 +570,8 @@ class ChangeType(enum.Enum):
     CHANGED_LINK = MODIFIED
     MODE = MODIFIED  # changed permissions
     OWNER = MODIFIED
+    CTIME = MODIFIED
+    MTIME = MODIFIED
 
     def short(self):
         """Get a short identifier for the change type."""
@@ -588,6 +629,8 @@ class DiffData:
     size: int  # size change (disk usage)
     mode_change: Optional[Tuple[str, str]] = None
     owner_change: Optional[Tuple[str, str, str, str]] = None
+    ctime_change: Optional[Tuple[QDateTime, QDateTime]] = None
+    mtime_change: Optional[Tuple[QDateTime, QDateTime]] = None
     modified: Optional[Tuple[int, int]] = None
 
 
@@ -798,6 +841,7 @@ class DiffTree(FileTreeModel[DiffData]):
 
             modified_template = self.tr("Added {}, deleted {}")
             owner_template = "{: <10} -> {: >10}"
+            time_template = "{}: {} -> {}"
             permission_template = "{} -> {}"
 
             # format
@@ -844,4 +888,20 @@ class DiffTree(FileTreeModel[DiffData]):
                     "{}:{}".format(item.data.owner_change[2], item.data.owner_change[3]),
                 )
 
+            if item.data.ctime_change:
+                tooltip += '\n'
+                tooltip += time_template.format(
+                    "Creation Time",
+                    QLocale.system().toString(item.data.ctime_change[0], QLocale.FormatType.ShortFormat),
+                    QLocale.system().toString(item.data.ctime_change[1], QLocale.FormatType.ShortFormat),
+                )
+
+            if item.data.mtime_change:
+                tooltip += '\n'
+                tooltip += time_template.format(
+                    "Modification Time",
+                    QLocale.system().toString(item.data.mtime_change[0], QLocale.FormatType.ShortFormat),
+                    QLocale.system().toString(item.data.mtime_change[1], QLocale.FormatType.ShortFormat),
+                )
+
             return tooltip
